M_U_list_cpp: Create 3D Array from List of Factor Matrices (C++ version)

View source: R/RcppExports.R

M_U_list_cppR Documentation

Create 3D Array from List of Factor Matrices (C++ version)

Description

General version that takes a list of factor matrices. For NetworkChange, typically called with list(U, U, V) for undirected networks.

Usage

M_U_list_cpp(U_list)

Arguments

U_list

List of factor matrices

Value

Array with dimensions corresponding to the rows of each factor matrix


NetworkChange documentation built on April 7, 2026, 9:07 a.m.