| M_U_list_cpp | R Documentation |
General version that takes a list of factor matrices. For NetworkChange, typically called with list(U, U, V) for undirected networks.
M_U_list_cpp(U_list)
U_list |
List of factor matrices |
Array with dimensions corresponding to the rows of each factor matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.